@@ -49,7 +49,7 @@ use vars qw(
                 $START_TIME
                );
 
-$VERSION = '0.950501';
+$VERSION = '0.9506';
 
 $REQUEST_COUNT          = 1;
 
@@ -143,7 +143,11 @@ BEGIN {
 
         *_platform_getppid = \&_linux_getppid;
 
-        if (eval { require Linux::Smaps } && Linux::Smaps->new($$)) {
+        if (eval { require Linux::Smaps::Tiny }) {
+            $USE_SMAPS = 1;
+            *_platform_check_size = \&_linux_smaps_tiny_size_check;
+        }
+        elsif (eval { require Linux::Smaps } && Linux::Smaps->new($$)) {
             $USE_SMAPS = 1;
             *_platform_check_size = \&_linux_smaps_size_check;
         }
@@ -193,6 +197,15 @@ sub _linux_smaps_size_check {
     return ($s->size, $s->shared_clean + $s->shared_dirty);
 }
 
+sub _linux_smaps_tiny_size_check {
+    my $class = shift;
+
+    return $class->_linux_size_check() unless $USE_SMAPS;
+
+    my $s = Linux::Smaps::Tiny::get_smaps_summary();
+    return ($s->{Size}, $s->{Shared_Clean} + $s->{Shared_Dirty});
+}
+
 sub _linux_size_check {
     my $class = shift;
 
